@@ -202,8 +202,6 @@ int SimonSolver::get_possible_moves(int *a, int *numout)
         conti[j]++;
     }
 
-    bool foundgood = false;
-
     for(int i=0; i<10; ++i)
     {
         int len = Wlen[i];
@@ -233,10 +231,6 @@ int SimonSolver::get_possible_moves(int *a, int *numout)
                      RANK(card) == RANK(*Wp[j]) - 1 )
                 {
                     allowed = true;
-#if 0
-                    if ( ( SUIT( card ) != SUIT( *Wp[j] ) ) && foundgood )
-                        allowed = false; // make the tree simpler
-#endif
                 }
                 if ( Wlen[j] == 0 && !wasempty )
                 {
@@ -253,11 +247,6 @@ int SimonSolver::get_possible_moves(int *a, int *numout)
                          !DOWN( card_below ) &&
                          RANK( card_below ) == RANK( card ) + 1 )
                     {
-#if 0
-                        printcard( card_below, stderr );
-                        printcard( card, stderr );
-                        fprintf( stderr, "%d %d %d %d %d\n", i, j, conti[i], conti[j],l );
-#endif
                         if ( conti[j]+l != 13 || conti[i]>conti[j]+l || SUIT( card ) != SUIT( *Wp[j] ) ) {
                             // fprintf( stderr, "continue\n" );
                             continue;
@@ -277,13 +266,13 @@ int SimonSolver::get_possible_moves(int *a, int *numout)
                     if ( cont )
                         cont += l;
                     mp->pri = 8 * cont + qMax( 0, 10 - Wlen[i] );
-                    if ( Wlen[j] )
-                        if ( SUIT( card ) != SUIT( *Wp[j] ) )
+                    if ( Wlen[j] ) {
+                        if ( SUIT( card ) != SUIT( *Wp[j] ) ) {
                             mp->pri /= 2;
-                        else
-                            foundgood = true;
-                    else
+                        }
+                    } else {
                         mp->pri = 2; // TODO: it should depend on the actual stack's order
+                    }
                     if ( Wlen[i] == l+1 )
                         mp->pri = qMin( 127, mp->pri + 20 );
                     else
@@ -296,12 +285,6 @@ int SimonSolver::get_possible_moves(int *a, int *numout)
                         card_t top = W[i][Wlen[i]-l-2];
                         card_t theone = W[i][Wlen[i]-conti_pos-1];
                         card_t below = W[i][Wlen[i]-conti_pos-2];
-#if 0
-                        printcard( top, stderr );
-                        printcard( theone, stderr );
-                        printcard( below, stderr );
-                        fputc( '\n', stderr );
-#endif
                         if ( SUIT( top ) != SUIT( below ) || DOWN( below ) )
                             break;
                         if ( RANK( theone ) !=
